pub struct FulfillmentPreview {
pub shipping_speed_category: ShippingSpeedCategory,
pub scheduled_delivery_info: Option<Box<ScheduledDeliveryInfo>>,
pub is_fulfillable: bool,
pub is_cod_capable: bool,
pub estimated_shipping_weight: Option<Box<Weight>>,
pub estimated_fees: Option<Vec<Fee>>,
pub fulfillment_preview_shipments: Option<Vec<FulfillmentPreviewShipment>>,
pub unfulfillable_preview_items: Option<Vec<UnfulfillablePreviewItem>>,
pub order_unfulfillable_reasons: Option<Vec<String>>,
pub marketplace_id: String,
pub feature_constraints: Option<Vec<FeatureSettings>>,
}Expand description
FulfillmentPreview : Information about a fulfillment order preview, including delivery and fee information based on shipping method.
Fields
shipping_speed_category: ShippingSpeedCategoryscheduled_delivery_info: Option<Box<ScheduledDeliveryInfo>>is_fulfillable: boolWhen true, this fulfillment order preview is fulfillable.
is_cod_capable: boolWhen true, this fulfillment order preview is for COD (Cash On Delivery).
estimated_shipping_weight: Option<Box<Weight>>estimated_fees: Option<Vec<Fee>>An array of fee type and cost pairs.
fulfillment_preview_shipments: Option<Vec<FulfillmentPreviewShipment>>An array of fulfillment preview shipment information.
unfulfillable_preview_items: Option<Vec<UnfulfillablePreviewItem>>An array of unfulfillable preview item information.
order_unfulfillable_reasons: Option<Vec<String>>marketplace_id: StringThe marketplace the fulfillment order is placed against.
feature_constraints: Option<Vec<FeatureSettings>>A list of features and their fulfillment policies to apply to the order.
Implementations
sourceimpl FulfillmentPreview
impl FulfillmentPreview
sourcepub fn new(
shipping_speed_category: ShippingSpeedCategory,
is_fulfillable: bool,
is_cod_capable: bool,
marketplace_id: String
) -> FulfillmentPreview
pub fn new(
shipping_speed_category: ShippingSpeedCategory,
is_fulfillable: bool,
is_cod_capable: bool,
marketplace_id: String
) -> FulfillmentPreview
Information about a fulfillment order preview, including delivery and fee information based on shipping method.